==> cloud-3.2.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Vpc/InternetGatewayAttachForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Vpc;

use Drupal\aws_cloud\Form\Ec2\AwsDeleteForm;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\cloud\Traits\CloudContentEntityTrait;

/**
 * Internet Gateway Attach form.
 */
class InternetGatewayAttachForm extends AwsDeleteForm {

  use CloudContentEntityTrait;

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $entity = $this->entity;

    return $this->t('Are you sure you want to attach internet gateway: %name?', [
      '%name' => $entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Attach');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    $entity = $this->entity;

    $module_name = $this->getModuleName($entity);
    $internet_gateway_id = $entity->getInternetGatewayId();
    $internet_gateway_link = $this->entityLinkRenderer->renderViewElement(
      $internet_gateway_id,
      "{$module_name}_internet_gateway",
      'internet_gateway_id',
      [],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    return $this->t('<h2>Internet Gateway Information:</h2><ul><li>Internet Gateway: %internet_gateway</li></ul>', [
      '%internet_gateway' => Markup::create($internet_gateway_link['#markup']),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }

    $vpcs = $this->getVpcs();

    if (!empty($vpcs)) {
      $form['vpc_id'] = [
        '#type'          => 'select',
        '#title'         => $this->t('VPC CIDR (ID)'),
        '#options'       => $vpcs,
        '#default_value' => $this->entity->getVpcId(),
        '#required'      => TRUE,
      ];
    }
    else {
      $form['message'] = [
        '#markup' => '<h1>' . $this->t('No VPCs available. Internet Gateway cannot be attached.') . '</h1>',
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);

    if (empty($this->getVpcs())) {
      unset($actions['submit']);
    }

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\aws_cloud\Entity\Vpc\InternetGateway $entity */
    $entity = $this->entity;

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $vpc_id = $form_state->getValue('vpc_id');
    $internet_gateway_id = $entity->getInternetGatewayId();

    $this->ec2Service->setCloudContext($this->entity->getCloudContext());
    $result = $this->ec2Service->attachInternetGateway([
      'InternetGatewayId' => $internet_gateway_id,
      'VpcId' => $vpc_id,
    ]);

    if ($result !== NULL) {

      // Update the internet gateway.
      $this->ec2Service->updateInternetGateways([
        'InternetGatewayIds' => [$internet_gateway_id],
      ], FALSE);

      $this->clearCacheValues();

      $internet_gateway_link = $this->entityLinkRenderer->renderViewElement(
        $internet_gateway_id,
        "{$module_name}_internet_gateway",
        'internet_gateway_id',
        [],
        '',
        EntityLinkWithNameHtmlGenerator::class
      );

      $vpc_link = $this->entityLinkRenderer->renderViewElement(
        $vpc_id,
        "{$module_name}_vpc",
        'vpc_id',
        [],
        '',
        EntityLinkWithNameHtmlGenerator::class
      );

      $this->messenger->addStatus($this->t('The Internet Gateway %internet_gateway is attached to VPC %vpc.', [
        '%internet_gateway' => Markup::create($internet_gateway_link['#markup']),
        '%vpc' => Markup::create($vpc_link['#markup']),
      ]));

      $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);
    }
  }

  /**
   * Get VPCs that can be attached to a internet gateway.
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   The VPC Entities.
   */
  private function getVpcs() {
    $this->ec2Service->setCloudContext($this->entity->getCloudContext());
    $vpcs = $this->ec2Service->getVpcs();
    ksort($vpcs);

    $result = $this->ec2Service->describeInternetGateways();
    foreach ($result['InternetGateways'] as $gateway) {
      if (empty($gateway['Attachments'])) {
        continue;
      }
      unset($vpcs[$gateway['Attachments'][0]['VpcId']]);
    }

    return $vpcs;
  }

}

==> cloud-4.0.0.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Vpc/InternetGatewayAttachForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Vpc;

use Drupal\aws_cloud\Form\Ec2\AwsDeleteForm;
use Drupal\aws_cloud\Traits\AwsCloudFormTrait;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Markup;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Internet Gateway Attach form.
 */
class InternetGatewayAttachForm extends AwsDeleteForm {

  use AwsCloudFormTrait;

  use CloudContentEntityTrait;

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    $entity = $this->entity;

    return $this->t('Are you sure you want to attach internet gateway: %name?', [
      '%name' => $entity->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText(): TranslatableMarkup {
    return $this->t('Attach');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    $entity = $this->entity;

    $module_name = $this->getModuleName($entity);
    $internet_gateway_id = $entity->getInternetGatewayId();
    $internet_gateway_link = $this->entityLinkRenderer->renderViewElement(
      $internet_gateway_id,
      "{$module_name}_internet_gateway",
      'internet_gateway_id',
      [],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    return $this->t('<h2>Internet Gateway Information:</h2><ul><li>Internet Gateway: %internet_gateway</li></ul>', [
      '%internet_gateway' => Markup::create($internet_gateway_link['#markup']),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }

    $vpcs = $this->getVpcs();

    if (!empty($vpcs)) {
      $form['vpc_id'] = [
        '#type'          => 'select',
        '#title'         => $this->t('VPC CIDR (ID)'),
        '#options'       => $vpcs,
        '#default_value' => $this->entity->getVpcId(),
        '#required'      => TRUE,
      ];
    }
    else {
      $form['message'] = [
        '#markup' => '<h1>' . $this->t('No VPCs available. Internet Gateway cannot be attached.') . '</h1>',
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state): array {
    $actions = parent::actions($form, $form_state);

    if (empty($this->getVpcs())) {
      unset($actions['submit']);
    }

    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    /** @var \Drupal\aws_cloud\Entity\Vpc\InternetGateway $entity */
    $entity = $this->entity;

    // Get module name.
    $module_name = $this->getModuleName($entity);

    $vpc_id = $form_state->getValue('vpc_id');
    $internet_gateway_id = $entity->getInternetGatewayId();

    $form_state->setRedirect("view.{$entity->getEntityTypeId()}.list", ['cloud_context' => $entity->getCloudContext()]);

    $this->ec2Service->setCloudContext($this->entity->getCloudContext());
    $result = $this->ec2Service->attachInternetGateway([
      'InternetGatewayId' => $internet_gateway_id,
      'VpcId' => $vpc_id,
    ]);

    if ($result === NULL) {
      return;
    }

    $internet_gateway_link = $this->entityLinkRenderer->renderViewElement(
      $internet_gateway_id,
      "{$module_name}_internet_gateway",
      'internet_gateway_id',
      [],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $vpc_link = $this->entityLinkRenderer->renderViewElement(
      $vpc_id,
      "{$module_name}_vpc",
      'vpc_id',
      [],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    if (!empty($result['SendToWorker'])) {
      $this->messenger->addStatus($this->t('The Internet Gateway %internet_gateway will be attached to VPC %vpc remotely.', [
        '%internet_gateway' => Markup::create($internet_gateway_link['#markup']),
        '%vpc' => Markup::create($vpc_link['#markup']),
      ]));
      return;
    }

    $this->messenger->addStatus($this->t('The Internet Gateway %internet_gateway is attached to VPC %vpc.', [
      '%internet_gateway' => Markup::create($internet_gateway_link['#markup']),
      '%vpc' => Markup::create($vpc_link['#markup']),
    ]));

    // Update the internet gateway.
    $this->ec2Service->updateInternetGateways([
      'InternetGatewayIds' => [$internet_gateway_id],
    ], FALSE);

    $this->clearCacheValues($entity->getCacheTags());
    $this->dispatchSubmitEvent($entity);
  }

  /**
   * Get VPCs that can be attached to a internet gateway.
   *
   * @return \Drupal\Core\Entity\EntityInterface[]
   *   The VPC Entities.
   */
  private function getVpcs(): array {
    $vpcs = $this->getVpcOptions($this->entity->getCloudContext());
    natcasesort($vpcs);

    $gateways = $this->entityTypeManager
      ->getStorage('aws_cloud_internet_gateway')
      ->loadByProperties([
        'cloud_context' => $this->entity->getCloudContext(),
      ]);

    foreach ($gateways as $gateway) {
      if (empty($gateway->getVpcId())) {
        continue;
      }
      unset($vpcs[$gateway->getVpcId()]);
    }

    return $vpcs;
  }

}
